==> gwt-openlayers-client-0.9.jar: org/gwtopenmaps/openlayers/client/control/ControlImpl.java <==
/**
 *
 *   Copyright 2013 sourceforge.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.gwtopenmaps.openlayers.client.control;

import org.gwtopenmaps.openlayers.client.util.JSObject;


/**
 *
 * @author Erdem Gunay
 *
 */
class ControlImpl
{

    public static native boolean activate(JSObject self) /*-{
        return self.activate();
    }-*/;

    public static native boolean deactivate(JSObject self) /*-{
        return self.deactivate();
    }-*/;

    public static native String getControlId(JSObject self) /*-{
        return self.id;
    }-*/;

    public static native boolean isActive(JSObject self)/*-{
        return (self.active === null) ? false : self.active;
    }-*/;

    public static native String getZIndex(JSObject self) /*-{
        return self.div.style.zIndex;
    }-*/;

    public static native void enable(JSObject control) /*-{
        control.active = true;
        control.handler.activate();
    }-*/;

    public static native void disable(JSObject control) /*-{
        control.active = false;
        control.handler.deactivate();
    }-*/;

    public static native JSObject getLayer(JSObject self) /*-{
        return self.handler.layer;
    }-*/;

}

==> gwt-openlayers-client-1.0.jar: org/gwtopenmaps/openlayers/client/control/ControlImpl.java <==
/**
 *
 *   Copyright 2014 sourceforge.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package org.gwtopenmaps.openlayers.client.control;

import org.gwtopenmaps.openlayers.client.util.JSObject;


/**
 *
 * @author Erdem Gunay
 *
 */
class ControlImpl
{

    public static native boolean activate(JSObject self) /*-{
        return self.activate();
    }-*/;

    public static native boolean deactivate(JSObject self) /*-{
        return self.deactivate();
    }-*/;

    public static native String getControlId(JSObject self) /*-{
        return self.id;
    }-*/;

    public static native boolean isActive(JSObject self)/*-{
        return (self.active == null) ? false : self.active;
    }-*/;

    public static native String getZIndex(JSObject self) /*-{
        return self.div.style.zIndex;
    }-*/;

    public static native void enable(JSObject control) /*-{
        control.active = true;
        control.handler.activate();
    }-*/;

    public static native void disable(JSObject control) /*-{
        control.active = false;
        control.handler.deactivate();
    }-*/;

    public static native JSObject getLayer(JSObject self) /*-{
        return self.handler.layer;
    }-*/;
    
    public static native void destroy(JSObject self) /*-{
        return self.destroy();
    }-*/;

}
